@@ -2,11 +2,10 @@
 
 # rendy  : 1191668125, 5915945719, 901878554
 # risman : 182990552, 844432220
-# yanto : 730988759, 1883126074
+# yanto : 730988759
 # kenkan : 1607338903
 # kyy : 1663258664
 # rizz : 951454060
-# dex : 1924219811
 
 DEVS = [
     1191668125,
@@ -15,11 +14,9 @@ DEVS = [
     844432220,
     730988759,
     1607338903,
-    1883126074,
     1663258664,
     951454060,
     901878554,
-    1924219811,
 ]
 
 # jangan hapus grup && gua gban lo
